@@ -306,7 +306,7 @@ class Calendar_Module_Model extends Vtiger_Module_Model {
 		$currentUser = Users_Record_Model::getCurrentUserModel();
 		if($currentUser->isAdminUser()) {
 			$query = "SELECT userlabel, id AS userid
-					FROM vtiger_users WHERE status='Active' AND (user_name != 'admin' OR is_owner = 1) AND id <> ?";
+					FROM vtiger_users WHERE status='Active' AND id <> ?";
 			$result = $db->pquery($query, array($id));
 		} else {
 			$query = "SELECT vtiger_users.userlabel, vtiger_users.id AS userid
@@ -763,6 +763,7 @@ class Calendar_Module_Model extends Vtiger_Module_Model {
 
 	public function getAllTasksbyPriority($conditions = false, $pagingModel) {
 		global $current_user;
+		$currentUserModel = Users_Record_Model::getCurrentUserModel();
 		$db = PearDatabase::getInstance();
 
 		$queryGenerator = new QueryGenerator("Calendar",$current_user);
@@ -814,6 +815,15 @@ class Calendar_Module_Model extends Vtiger_Module_Model {
 										break;
 					case "datetime":	$value = Vtiger_Date_UIType::getDisplayDateValue($value);
 										break;
+
+					// Assigning the time value to the basic info, which we use for the quick edit of tasks ex: start time.
+					case "time":		$value = Vtiger_Time_UIType::getDisplayTimeValue($value);
+										$value = $fieldModel->getDisplayValue($value);
+										$hourFormat = $currentUserModel->get('hour_format');
+										if($hourFormat == '24') {
+											$value= date('H:i', strtotime($value));
+										}
+										break;
 				}
 				$basicInfo[$fieldName] = $value;
 			}
@@ -863,15 +873,19 @@ class Calendar_Module_Model extends Vtiger_Module_Model {
 			$currentTime = time();
 			$date = date('Y-m-d', strtotime("+$activityReminder seconds", $currentTime));
 			$time = date('H:i',   strtotime("+$activityReminder seconds", $currentTime));
+			$dateAndTime = $date.' '.$time;
 			$reminderActivitiesResult = "SELECT reminderid, recordid FROM vtiger_activity_reminder_popup
 								INNER JOIN vtiger_activity on vtiger_activity.activityid = vtiger_activity_reminder_popup.recordid
 								INNER JOIN vtiger_crmentity ON vtiger_activity_reminder_popup.recordid = vtiger_crmentity.crmid
 								WHERE vtiger_activity_reminder_popup.status = 0
 								AND vtiger_crmentity.smownerid = ? AND vtiger_crmentity.deleted = 0
-								AND ((DATE_FORMAT(vtiger_activity_reminder_popup.date_start,'%Y-%m-%d') <= ?)
-								AND (TIME_FORMAT(vtiger_activity_reminder_popup.time_start,'%H:%i') <= ?))
+								and CONCAT(
+									DATE_FORMAT(vtiger_activity_reminder_popup.date_start,'%Y-%m-%d'),
+									' ',
+									TIME_FORMAT(vtiger_activity_reminder_popup.time_start,'%H:%i')
+								) <= ?
 								AND vtiger_activity.eventstatus <> 'Held' AND (vtiger_activity.status <> 'Completed' OR vtiger_activity.status IS NULL) LIMIT 20";
-			$result = $db->pquery($reminderActivitiesResult, array($currentUserModel->getId(), $date, $time));
+			$result = $db->pquery($reminderActivitiesResult, array($currentUserModel->getId(), $dateAndTime));
 			$rows = $db->num_rows($result);
 			for($i=0; $i<$rows; $i++) {
 				$recordId = $db->query_result($result, $i, 'recordid');
