@@ -93,8 +93,8 @@ $languageStrings = array(
 	'Assigned To'                  => 'Assigned To'                 , 
 	'LBL_LOADING'                  => 'Loading...'                  , 
 	'LBL_LOADING_WIDGET'           => 'Loading Widget'              , 
-	'LBL_LOADING_LISTVIEW_CONTENTS' => 'Loading, Please wait.'       , 
-	'LBL_UPDATES'                  => 'Recent Updates'                     , 
+	'LBL_LOADING_LISTVIEW_CONTENTS' => 'Loading, Please wait.'      , 
+	'LBL_UPDATES'                  => 'Updates'                     , 
 	'LBL_SHOW_FULL_DETAILS'        => 'Show Full Details'           , // TODO: Review
 	'LBL_SUMMARY_DETAILS'          => 'Summary Details'             ,
 	'LBL_ADD_NEW_COMMENT'          => 'Add New Comment'             ,
@@ -246,10 +246,10 @@ $languageStrings = array(
 	'LBL_MORE_CURRENCIES'          => 'more currencies'             ,
 	'LBL_SET_TAX_FOR'              => 'Set Tax for'                 , // TODO: Review
 	'LBL_GROUP_TAX'                => 'Group Tax'                   , // TODO: Review
-	'LBL_BILLING_ADDRESS_FROM'     => 'Copy Billing Address from'   , // TODO: Review
-	'LBL_SHIPPING_ADDRESS_FROM'    => 'Copy Shipping Address from'  , // TODO: Review
-	'LBL_COPY_SHIPPING_ADDRESS'    => 'Shipping Address'            , // TODO: Review
-	'LBL_COPY_BILLING_ADDRESS'     => 'Billing Address'             , // TODO: Review
+	'LBL_BILLING_ADDRESS_FROM'     => 'Copy Invoice Address from'   , // TODO: Review
+	'LBL_SHIPPING_ADDRESS_FROM'    => 'Copy Delivery Address from'  , // TODO: Review
+	'LBL_COPY_SHIPPING_ADDRESS'    => 'Delivery Address'            , // TODO: Review
+	'LBL_COPY_BILLING_ADDRESS'     => 'Invoice Address'             , // TODO: Review
 	'LBL_OVERALL_DISCOUNT'			=> 'Overall Discount'			,
 	'LBL_CHARGES'					=> 'Charges'					,
 	'LBL_CHARGES_TOTAL'				=> 'Charges Total'				,
@@ -352,6 +352,8 @@ $languageStrings = array(
 	'LBL_LAST_60_DAYS'             => 'Last 60 Days'                ,
 	'LBL_LAST_90_DAYS'             => 'Last 90 Days'                ,
 	'LBL_LAST_120_DAYS'            => 'Last 120 Days'               ,
+	'LBL_NEXT_7_DAYS'             => 'Next 7 Days'                ,   
+	'LBL_NEXT_14_DAYS'             => 'Next 14 Days'                ,
 	'LBL_NEXT_30_DAYS'             => 'Next 30 Days'                ,
 	'LBL_NEXT_60_DAYS'             => 'Next 60 Days'                ,
 	'LBL_NEXT_90_DAYS'             => 'Next 90 Days'                ,
@@ -396,11 +398,11 @@ $languageStrings = array(
 	'Apparel'                      => 'Apparel'                     ,
 	'Banking'                      => 'Banking'                     ,
 	'Billing Address'              => 'Invoice Address'             ,
-	'Billing City'                 => 'Billing City'                ,
-	'Billing Code'                 => 'Billing Postal Code'         ,
-	'Billing Country'              => 'Billing Country'             ,
-	'Billing Po Box'               => 'Billing P.O. Box'            ,
-	'Billing State'                => 'Billing State'               ,
+	'Billing City'                 => 'Invoice City'                ,
+	'Billing Code'                 => 'Invoice Postal Code'         ,
+	'Billing Country'              => 'Invoice Country'             ,
+	'Billing Po Box'               => 'Invoice P.O. Box'            ,
+	'Billing State'                => 'Invoice State'               ,
 	'Biotechnology'                => 'Biotechnology'               ,
 	'FedEx'                        => 'FedEx'                       ,
 	'UPS'                          => 'UPS'                         ,
@@ -458,11 +460,11 @@ $languageStrings = array(
 	'Contact Name'                 => 'Contact Name'                ,
 	'Conversion Rate'              => 'Conversion Rate'             ,
 	'Shipping Address'             => 'Delivery Address'            ,
-	'Shipping City'                => 'Shipping City'               ,
-	'Shipping State'               => 'Shipping State'              ,
-	'Shipping Code'                => 'Shipping Postal Code'        ,
-	'Shipping Country'             => 'Shipping Country'            ,
-	'Shipping Po Box'              => 'Shipping P.O. Box'           ,
+	'Shipping City'                => 'Delivery City'               ,
+	'Shipping State'               => 'Delivery State'              ,
+	'Shipping Code'                => 'Delivery Postal Code'        ,
+	'Shipping Country'             => 'Delivery Country'            ,
+	'Shipping Po Box'              => 'Delivery P.O. Box'           ,
 	'Country'                      => 'Country'                     ,
 	'Created'                      => 'Created'                     ,
 	'Approved'                     => 'Approved'                    ,
@@ -541,7 +543,7 @@ $languageStrings = array(
 	'Open Ticktes'                 => 'Open Tickets'                , // TODO: Review
 	'LBL_SELECT_STATUS'            => 'Select Status'               ,
 	'LBL_VTIGER_CRM_HONEST_OPEN_SOURCE' => 'vtiger CRM On Demand'        ,
-	'SINGLE_Accounts'              => 'Organization'                , // TODO: Review
+	'SINGLE_Accounts'              => 'Organisation'                , // TODO: Review
 	'SINGLE_Contacts'              => 'Contact'                     , // TODO: Review
 	'LBL_Sun'                      => 'Sun'                         , // TODO: Review
 	'LBL_Mon'                      => 'Mon'                         , // TODO: Review
@@ -638,7 +640,7 @@ $languageStrings = array(
 	'LBL_TRANSFER_OWNERSHIP' => 'Transfer Ownership',
 	'LBL_SELECT_RELATED_MODULES' => 'Select Related Modules',
 
-	'LBL_CUSTOMIZE_MAIN_MENU' => 'Customize Main Menu', //TODO REVIEW
+	'LBL_CUSTOMIZE_MAIN_MENU' => 'Customise Main Menu', //TODO REVIEW
 
 	//Comments Field Labels for Workflow
 	'Comment' => 'Comment',
@@ -671,7 +673,7 @@ $languageStrings = array(
     'Half-Yearly' => 'Half-Yearly',
     'LBL_FULLSCREEN' => 'Full Screen',
     'LBL_MODULE_DISABLED'          => ' Module is disabled'     ,
-    'Organization Name' => 'Organization Name',
+    'Organization Name' => 'Organisation Name',
     'LBL_WEEK' => 'Week',
     // Convert Leads and Potentials
     'LBL_CONVERT_ERROR_TITLE' => 'Modules Disabled'            ,
@@ -770,11 +772,11 @@ $languageStrings = array(
     //Singular Modulenames
     'SINGLE_Potentials' => 'Opportunity',
     'SINGLE_HelpDesk' => 'Ticket',
-    'SINGLE_Accounts' => 'Organization',
+    'SINGLE_Accounts' => 'Organisation',
     'SINGLE_Contacts' => 'Contact',
     'SINGLE_Project' => 'Project',
     'LBL_ROLLUP_COMMENTS_INFO' => "If Roll up is set to 'On' comments on related records will be shown. 
-                                   For example, if you are viewing comments on an Organization record, comments added to related Contacts, Opportunities, Tickets, ..etc would also be displayed.",
+                                   For example, if you are viewing comments on an Organisation record, comments added to related Contacts, Opportunities, Tickets, ..etc would also be displayed.",
     'LBL_ROLLUP_COMMENTS' => "Rollup Comments",
     'group' => 'Group',
     'individual' => 'Individual',
@@ -874,7 +876,7 @@ $languageStrings = array(
   'LBL_MODIFIED' => 'Modified',
   'Funnel Amount' => 'Total Amount by Sales stage',
   'LBL_TYPE_AND_SEARCH' => 'Type and Search',
-  'LBL_CUSTOMIZE' => 'Customize:',
+  'LBL_CUSTOMIZE' => 'Customise:',
   'LBL_LABELS' => 'Labels',
   'LBL_WORKFLOWS' => 'Workflows',
   'LBL_PICKLIST' => 'Picklists',
@@ -926,7 +928,7 @@ $languageStrings = array(
   'LBL_CANNOT_BE_CHANGED_LATER' => 'Cannot be changed later',
   'IMPORT_CONTACTS_GOOGLE_HELP_TEXT' => 'We can bring contacts from Google and <br> you can also enable bi-direction sync to keep our<br>
                                     Vtiger contacts and Google contacts(in selected group updated.<br>
-                                    Click the button to authorize and get Contacts from Google.',
+                                    Click the button to authorise and get Contacts from Google.',
   'IMPORT_CONTACTS_CSV_HELP_TEXT' => 'You can import Contacts from CSV file.',
   'IMPORT_CONTACTS_CSV_HELP_TEXT2' => 'To Import Opportunities, Leads, Tickets, please look for Actions > Import button on any of the
                                          list views.',
@@ -938,7 +940,7 @@ $languageStrings = array(
   'LBL_IMPORT_SYNC_INTIATED_MSG' => 'Your import is in progress. You will receive an email when import is completed.<br> Proceeding to Next step will not interrupt the import.',
   'LBL_TELL_US_ABOUT_YOU' => 'Help us by telling us about your Company',
   'TELL_US_ABOUT_YOU_HELP_TEXT' => 'We continue to make improvements to the CRM, and <br>
-                                      knowing our users better will help us prioritize enhancements.',
+                                      knowing our users better will help us prioritise enhancements.',
   'TELL_US_ABOUT_YOU_HELP_TEXT_2' => 'The data you submitted here will not be revealed to anyone <Br>
                                         outside Vtiger.',
   'LBL_IMPORT_CONTACTS' => 'Import Contacts',
@@ -996,6 +998,7 @@ $languageStrings = array(
   'LBL_MARKETING' => 'MARKETING',
   'LBL_SALES' => 'SALES',
   'LBL_PROJECT' => 'PROJECTS',
+	'LBL_TOOLS' => 'TOOLS',
   'LBL_TAGS' => 'Tags',
   'LBL_SHARE_TAGS' => 'Public Tags',
   'LBL_SHARE_TAG' => 'Share Tag',
@@ -1103,7 +1106,7 @@ $jsLanguageStrings = array(
 	'JS_LBL_ARE_YOU_SURE_YOU_WANT_TO_DELETE' => 'Are you sure that you want to delete?',
 	'OVERWRITE_EXISTING_MSG1'      => 'Overwrite the existing address with the selected address?',
 	'OVERWRITE_EXISTING_MSG2'      => 'Address Details'             ,
-	'SINGLE_Accounts'              => 'Organization'                ,
+	'SINGLE_Accounts'              => 'Organisation'                ,
 	'SINGLE_Contacts'              => 'Contact'                     ,
 	'LBL_DELETE_CONFIRMATION'      => 'Are you sure you want to Delete?',
 	'LBL_MASS_DELETE_CONFIRMATION' => 'Are you sure you want to delete the selected Records?',
@@ -1160,9 +1163,9 @@ $jsLanguageStrings = array(
 	'JS_INFORMATION'               => 'Information'                 , // TODO: Review
 	'JS_DO_NOT_HAVE_AN_EMAIL_ID'   => 'does not have an email address', // TODO: Review
 	'NONE_OF_THE_FIELD_VALUES_ARE_CHANGED_IN_MASS_EDIT' => 'None of the field values are changed in Mass Edit', // TODO: Review
-	'JS_PLEASE_SELECT_AN_ACCOUNT_TO_COPY_ADDRESS' => 'Please select an Organization to copy address', // TODO: Review
+	'JS_PLEASE_SELECT_AN_ACCOUNT_TO_COPY_ADDRESS' => 'Please select an Organisation to copy address', // TODO: Review
 	'JS_PLEASE_SELECT_AN_CONTACT_TO_COPY_ADDRESS' => 'Please select a Contact to copy address', // TODO: Review
-	'JS_SELECTED_ACCOUNT_DOES_NOT_HAVE_AN_ADDRESS' => 'Selected Organization does not contain address to copy', // TODO: Review
+	'JS_SELECTED_ACCOUNT_DOES_NOT_HAVE_AN_ADDRESS' => 'Selected Organisation does not contain address to copy', // TODO: Review
 	'JS_SELECTED_CONTACT_DOES_NOT_HAVE_AN_ADDRESS' => 'Selected Contact does not contain address to copy', // TODO: Review
 	'JS_PLEASE_ENTER_PRIMARY_EMAIL_VALUE_TO_ENABLE_PORTAL_USER' => 'Please enter Primary email address to enable portal user', // TODO: Review
 	'JS_PRIMARY_EMAIL_FIELD_DOES_NOT_EXISTS' => 'Primary email field does not exist to enable portal user', // TODO: Review
@@ -1209,13 +1212,13 @@ $jsLanguageStrings = array(
     'JS_NO_EDIT_PERMISSION' => 'You don\'t have the permission to edit this event',
 
         //Google Synchronization
-        'SYNC_REMOVED_SUCCESSFULLY' => 'Google synchronization removed successfully.',
-        'REMOVE_SYNCHRONIZATION_MESSAGE' => 'Clicking on this will remove existing Gmail authentication. It will not delete any records which are already synchronized.',
-        'REMOVE_SYNCHRONIZATION' => 'Remove Synchronization',
+        'SYNC_REMOVED_SUCCESSFULLY' => 'Google synchronisation removed successfully.',
+        'REMOVE_SYNCHRONIZATION_MESSAGE' => 'Clicking on this will remove existing Gmail authentication. It will not delete any records which are already synchronised.',
+        'REMOVE_SYNCHRONIZATION' => 'Remove Synchronisation',
         'FIELD_MAPPING' => 'Field Mapping',
-        'LBL_SYNC_BUTTON' => 'Synchronize Now',
-        'LBL_SYNCRONIZING' => 'Synchronizing....',
-        'LBL_NOT_SYNCRONIZED' => 'You have not synchronized yet',
+        'LBL_SYNC_BUTTON' => 'Synchronise Now',
+        'LBL_SYNCRONIZING' => 'Synchronising....',
+        'LBL_NOT_SYNCRONIZED' => 'You have not synchronised yet',
         'LBL_FIELD_MAPPING' => 'Field Mapping',
 
         'LBL_RESTORE_CONFIRMATION' => 'Records previously assigned to this user will not be restored. Are you sure you want to restore this user?',
@@ -1333,7 +1336,7 @@ $jsLanguageStrings = array(
     'blog' => 'Blog',
     'home-page' => 'Homepage',
     'address' => 'Address',
-    'JS_REMOVE_SYNC_CONFIRMATION' => 'Remove synchronization will only remove existing authentication, it will not delete synchronized records. If you synchronize with same Google account again, duplicate records will be created. Are you sure you want to remove synchronization?',
+    'JS_REMOVE_SYNC_CONFIRMATION' => 'Remove synchronisation will only remove existing authentication, it will not delete synchronised records. If you synchronise with same Google account again, duplicate records will be created. Are you sure you want to remove synchronisation?',
     
     // Social Module Strings
     'JS_PLEASE_WAIT' => 'Please Wait...',
@@ -1357,7 +1360,7 @@ $jsLanguageStrings = array(
     //Office365
     'LBL_REMOVE_SYNC_CONFIRMATION' => 'Removes Authorization for Contacts, Calendars and Emails. Are you sure you want to remove sync?',
     'OFFICE365_SYNC_REMOVED_SUCCESSFULLY' => 'Office365 sync removed successfully',
-    'OFFICE365_REMOVE_SYNCHRONIZATION_MESSAGE' => 'Clicking on this will remove existing Office365 authentication. It will not delete any records which are already synchronized. It will not unregister the Vtiger app from you office365 account, to unregister visit https://myapps.microsoft.com/',
+    'OFFICE365_REMOVE_SYNCHRONIZATION_MESSAGE' => 'Clicking on this will remove existing Office365 authentication. It will not delete any records which are already synchronised. It will not unregister the Vtiger app from you office365 account, to unregister visit https://myapps.microsoft.com/',
     
     'JS_LOADING_COMMENTS' => 'Fetching Comments ...',
     'JS_PASSWORD_MISMATCH_ERROR' => 'Please re-enter passwords.  The "new password" and "confirm password" values do not match.',
@@ -1375,10 +1378,10 @@ $jsLanguageStrings = array(
   'JS_TAG_SAVED_SUCCESSFULLY' => 'Tag Saved Successfully',
   'JS_SUBJECT_VALUE_CANT_BE_EMPTY' => 'Subject value cannot be empty',
   'JS_PERCENTAGE_SHOULD_BE_LESS_THAN_100' => 'Percentage should be less than 100',
-  'LBL_DELETE_USER_CONFIRMATION' => 'When a User is deleted, the user will be marked as "Inactive" and no new records can be assigned to the User, and the user will not be able to login. Billing will stop for this user.If you need to reactivate a deleted user, you will need to send email to support@vtiger.com.Are you sure you want to delete?',
-  'JS_DUPLICATE_CREATION_CONFIRMATION' => 'Organization Name already Exists.Do you want to create a duplicate record?',
+  'LBL_DELETE_USER_CONFIRMATION' => 'When a user is deleted, the user will be marked as "Inactive" and no new records can be assigned to the user and the user will not be able to login. Billing will stop for this user. If you need to reactivate a deleted user, you will need to send email to support@vtiger.com. Are you sure you want to delete?',
+  'JS_DUPLICATE_CREATION_CONFIRMATION' => 'Organisation Name already Exists. Do you want to create a duplicate record?',
   'JS_SELECT_RECORDS_TO_MERGE_FROM_SAME_GROUP' => 'You have to select the records in the same groups for merging',
-  'JS_SELECT_ATLEAST_TWO_RECORD_FOR_MERGING' => 'Select atleast two records for merging',
+  'JS_SELECT_ATLEAST_TWO_RECORD_FOR_MERGING' => 'Select at least two records for merging',
   'JS_ALLOWED_TO_SELECT_MAX_OF_THREE_RECORDS' => 'You are allowed to select a maximum of three records',
   'JS_ARE_YOU_SURE_TO_DELETE_WIDGET' => 'Are you sure to delete widget',
   'JS_ARE_YOU_SURE_TO_DELETE_DASHBOARDTAB' => 'Are you sure to delete tab',
@@ -1457,10 +1460,10 @@ $jsLanguageStrings = array(
   'JS_ADD_MAX_15_ITEMS' => 'You can only add 15 items',
   'SINGLE_SLA' => 'SLA',
   'JS_EDIT_FIELDS' => '%s Fields & Layout',
-  'JS_MORE_VTIGER' => 'There are more records to be synchronized in vtiger',
-  'JS_MORE_GOOGLE' => 'There are more records to be synchronized in Google',
-  'JS_MORE_OFFICE365' => 'There are more records to be synchronized in Office365',
-  'JS_TOKEN_EXPIRED' => 'Office365 Authentication has expired. Click on Sign in with Office365 button to re-authorize.',
+  'JS_MORE_VTIGER' => 'There are more records to be synchronised in vtiger',
+  'JS_MORE_GOOGLE' => 'There are more records to be synchronised in Google',
+  'JS_MORE_OFFICE365' => 'There are more records to be synchronised in Office365',
+  'JS_TOKEN_EXPIRED' => 'Office365 Authentication has expired. Click on Sign in with Office365 button to re-authorise.',
   'JS_WISH_TO_PROCEED' => 'Are you sure you want to proceed?',
   'JS_SWITCH_TO_OLD_LOOK_CONFIRMATION_MESSAGE' => 'Some features, including notifications, picklist colors, follow record, are not available in old version. You may switch back to new version by choosing new version from top right menu.',
   'JS_PROCEED_OLD_VERSION' => 'Proceed to old version',
@@ -1495,4 +1498,5 @@ $jsLanguageStrings = array(
 	'JS_DUPLICATES_DETECTED' => 'Duplicate(s) detected!',
 	'JS_PASSWORD_MISMATCH_ERROR' => 'Please re-enter passwords. The "new password" and "confirm password" values do not match.',
 	'JS_LIST_DELETE_CONFIRMATION' => 'Are you sure you want to delete?',
-);
\ No newline at end of file
+	'JS_WIDGET_RESIZING_WAIT_MSG' => 'Widget contents will load after resizing.',
+);
